package com.iden.bms.schedule;



import com.iden.bms.service.VideoService;
import com.iden.common.cache.RedisKeyConstant;
import com.iden.common.cache.RedisUtil;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * 定时读取目录下图片，调用人脸识别引擎，把特征码入库
 */
@Configuration
@EnableScheduling
@EnableAsync
public class VideoSchedule {

    @Resource
    private VideoService videoService;
    @Resource
    private RedisUtil redisUtil;

    /**
     * 处理摄像头上传的视频
     */
    @Async
    @Scheduled(cron = "30 1/5 * * * ?")
    public void handleCameraVideo() {
        String key = RedisKeyConstant.HANDLE_CAMERA_VIDEO;
        String requestId = UUID.randomUUID().toString();
        boolean result = redisUtil.tryLock(key,requestId,10 * 60);
        try {
            if (result) {
                videoService.handleCameraVideo();
            }
        } catch (Exception e) {
            e.getMessage();
        }  finally {
            redisUtil.releaseLock(key,requestId);
        }

    }


}
